@@ -429,7 +429,7 @@ Converts a binary string of hinting code into a textual representation
     ['MIRP[18]'], ['MIRP[19]'], ['MIRP[1A]'], ['MIRP[1B]'], ['MIRP[1C]'], ['MIRP[1D]'], ['MIRP[1E]'], ['MIRP[1F]']);
 
     my ($i);
-    my (%hints) = map { $_->[0] => $i++ } @hints;
+    my (%hints) = map { $_->[0] => $i++ if (defined $_->[0]); } @hints;
 
     sub XML_binhint
     {
